==> kadaster-gds2-2.3-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstselectie/v20170401/ObjectFactory.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstselectie.v20170401;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.kadaster.schemas.gds2.afgifte_bestandenlijstselectie.v20170401 package. 
 * &lt;p&gt;An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _AfgifteSelectieCriteria_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstselectie/v20170401", "AfgifteSelectieCriteria");
    private final static QName _BestandKenmerken_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstselectie/v20170401", "BestandKenmerken");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.kadaster.schemas.gds2.afgifte_bestandenlijstselectie.v20170401
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link AfgifteSelectieCriteriaType }
     * 
     */
    public AfgifteSelectieCriteriaType createAfgifteSelectieCriteriaType() {
        return new AfgifteSelectieCriteriaType();
    }

    /**
     * Create an instance of {@link BestandKenmerkenType }
     * 
     */
    public BestandKenmerkenType createBestandKenmerkenType() {
        return new BestandKenmerkenType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AfgifteSelectieCriteriaType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link AfgifteSelectieCriteriaType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstselectie/v20170401", name = "AfgifteSelectieCriteria")
    public JAXBElement<AfgifteSelectieCriteriaType> createAfgifteSelectieCriteria(AfgifteSelectieCriteriaType value) {
        return new JAXBElement<AfgifteSelectieCriteriaType>(_AfgifteSelectieCriteria_QNAME, AfgifteSelectieCriteriaType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link BestandKenmerkenType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link BestandKenmerkenType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstselectie/v20170401", name = "BestandKenmerken")
    public JAXBElement<BestandKenmerkenType> createBestandKenmerken(BestandKenmerkenType value) {
        return new JAXBElement<BestandKenmerkenType>(_BestandKenmerken_QNAME, BestandKenmerkenType.class, null, value);
    }

}

==> kadaster-gds2-2.7-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstselectie/v20170401/ObjectFactory.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstselectie.v20170401;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.kadaster.schemas.gds2.afgifte_bestandenlijstselectie.v20170401 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _AfgifteSelectieCriteria_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstselectie/v20170401", "AfgifteSelectieCriteria");
    private final static QName _BestandKenmerken_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstselectie/v20170401", "BestandKenmerken");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.kadaster.schemas.gds2.afgifte_bestandenlijstselectie.v20170401
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link AfgifteSelectieCriteriaType }
     * 
     */
    public AfgifteSelectieCriteriaType createAfgifteSelectieCriteriaType() {
        return new AfgifteSelectieCriteriaType();
    }

    /**
     * Create an instance of {@link BestandKenmerkenType }
     * 
     */
    public BestandKenmerkenType createBestandKenmerkenType() {
        return new BestandKenmerkenType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AfgifteSelectieCriteriaType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link AfgifteSelectieCriteriaType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstselectie/v20170401", name = "AfgifteSelectieCriteria")
    public JAXBElement<AfgifteSelectieCriteriaType> createAfgifteSelectieCriteria(AfgifteSelectieCriteriaType value) {
        return new JAXBElement<AfgifteSelectieCriteriaType>(_AfgifteSelectieCriteria_QNAME, AfgifteSelectieCriteriaType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link BestandKenmerkenType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link BestandKenmerkenType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstselectie/v20170401", name = "BestandKenmerken")
    public JAXBElement<BestandKenmerkenType> createBestandKenmerken(BestandKenmerkenType value) {
        return new JAXBElement<BestandKenmerkenType>(_BestandKenmerken_QNAME, BestandKenmerkenType.class, null, value);
    }

}
